import psutil

from .base import BaseCollection
from .utils import get_human_readable_size


class MemoryCollector(BaseCollection):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    @property
    def memory(self):
        return psutil.virtual_memory()

    @property
    def available(self):
        return get_human_readable_size(self.memory.available)

    @property
    def total(self):
        return get_human_readable_size(self.memory.total)

    @property
    def percentage(self):
        return self.memory.percent

    @property
    def used(self):
        return get_human_readable_size(self.memory.used)

    @property
    def free(self):
        return get_human_readable_size(self.memory.free)

    @property
    def active(self):
        return get_human_readable_size(self.memory.active)

    @property
    def inactive(self):
        return get_human_readable_size(self.memory.inactive)

    @property
    def cached(self):
        return get_human_readable_size(self.memory.cached)

    def to_dict(self):
        return {
            "available": self.available,
            "free": self.free,
            "used": self.used,
            "active": self.active,
            "inactive": self.inactive,
            # "cached": self.cached
        }



import psutil

from .base import BaseCollection
from .utils import get_human_readable_size


class Partition:
    def __init__(self, device, mountpoint):
        self.device = device
        self.mountpoint = mountpoint

    @property
    def total(self):
        return get_human_readable_size(psutil.disk_usage(self.mountpoint).total)

    @property
    def used(self):
        return get_human_readable_size(psutil.disk_usage(self.mountpoint).used)

    @property
    def free(self):
        return get_human_readable_size(psutil.disk_usage(self.mountpoint).free)

    @property
    def percentage(self):
        return get_human_readable_size(psutil.disk_usage(self.mountpoint).percent)

    def to_dict(self):
        return {
            "device": self.device,
            "mountpoint": self.mountpoint,
            "total": self.total,
            "used": self.used,
            "free": self.free,
            "percentage": self.percentage,
        }


class DiskCollector(BaseCollection):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    @staticmethod
    def to_dict():
        return [
            Partition(device=partition.device, mountpoint=partition.mountpoint).to_dict()
            for partition in psutil.disk_partitions()
        ]



from datetime import datetime
import socket
import requests


class BaseCollection:
    def __init__(self, *args, **kwargs):
        pass

    @property
    def hostname(self):
        """Return host name"""
        return socket.gethostname()

    @property
    def ipaddress(self):
        """Property to retrieve the public IP address of the host"""
        return requests.get("https://api.ipify.org").content.decode("utf8")

    @property
    def event_timestamp(self):
        return datetime.utcnow().isoformat()
